@@ -1,5 +1,7 @@
 #include "hid_mouse.h"
 
+#include <stdint.h>
+
 // 1 byte for buttons + padding, 1 byte for X position, 1 byte for Y position,
 // 1 byte for wheel motion
 #define SC_HID_MOUSE_INPUT_SIZE 4
@@ -190,7 +192,6 @@ sc_hid_mouse_generate_input_from_scroll(struct sc_hid_input *hid_input,
 
 void sc_hid_mouse_generate_open(struct sc_hid_open *hid_open) {
     hid_open->hid_id = SC_HID_ID_MOUSE;
-    hid_open->name = NULL; // No name specified after "scrcpy"
     hid_open->report_desc = SC_HID_MOUSE_REPORT_DESC;
     hid_open->report_desc_size = sizeof(SC_HID_MOUSE_REPORT_DESC);
 }
